@@ -324,10 +324,10 @@ class HanLPClient(object):
             HanLP.abstract_meaning_representation('The boy wants the girl to believe him.',
                                                   language='en')
 
-        .. image:: https://hanlp.hankcs.com/proxy/amr?tok=%E7%94%B7%E5%AD%A9%20%E5%B8%8C%E6%9C%9B%20%E5%A5%B3%E5%AD%A9%20%E7%9B%B8%E4%BF%A1%20%E4%BB%96%20%E3%80%82&language=zh&scale=1
+        .. image:: https://hanlp.hankcs.com/backend/v2/amr_svg?tokens=%E7%94%B7%E5%AD%A9%20%E5%B8%8C%E6%9C%9B%20%E5%A5%B3%E5%AD%A9%20%E7%9B%B8%E4%BF%A1%20%E4%BB%96%20%E3%80%82&language=zh&scale=1
             :alt: Abstract Meaning Representation
 
-        .. image:: https://hanlp.hankcs.com/proxy/amr?tok=The%20boy%20wants%20the%20girl%20to%20believe%20him%20.&language=en&scale=1
+        .. image:: https://hanlp.hankcs.com/backend/v2/amr_svg?tokens=The%20boy%20wants%20the%20girl%20to%20believe%20him%20.&language=en&scale=1
             :alt: Abstract Meaning Representation
 
         """
@@ -371,3 +371,72 @@ class HanLPClient(object):
             'language': language or self._language,
             'topk': topk,
         })
+
+    def extractive_summarization(
+            self,
+            text: str,
+            topk: int = 3,
+            language: str = None,
+    ) -> Dict[str, float]:
+        """ Single document summarization is the task of selecting a subset of the sentences which best
+        represents a summary of the document, with a balance of salience and redundancy.
+
+        Args:
+            text: The text content of the document.
+            topk: The maximum number of top-K ranked sentences. Note that due to Trigram Blocking tricks, the actual
+                number of returned sentences could be less than ``topk``.
+            language: The language of input text or tokens. ``None`` to use the default language on server.
+
+        Returns:
+            A dictionary containing each sentence and its ranking score :math:`s \in [0, 1]`.
+
+        Examples::
+
+            HanLP.extractive_summarization('''
+            据DigiTimes报道，在上海疫情趋缓，防疫管控开始放松后，苹果供应商广达正在逐步恢复其中国工厂的MacBook产品生产。
+            据供应链消息人士称，生产厂的订单拉动情况正在慢慢转强，这会提高MacBook Pro机型的供应量，并缩短苹果客户在过去几周所经历的延长交货时间。
+            仍有许多苹果笔记本用户在等待3月和4月订购的MacBook Pro机型到货，由于苹果的供应问题，他们的发货时间被大大推迟了。
+            据分析师郭明錤表示，广达是高端MacBook Pro的唯一供应商，自防疫封控依赖，MacBook Pro大部分型号交货时间增加了三到五周，
+            一些高端定制型号的MacBook Pro配置要到6月底到7月初才能交货。
+            尽管MacBook Pro的生产逐渐恢复，但供应问题预计依然影响2022年第三季度的产品销售。
+            苹果上周表示，防疫措施和元部件短缺将继续使其难以生产足够的产品来满足消费者的强劲需求，这最终将影响苹果6月份的收入。
+            ''')
+            # Output:
+            {'据DigiTimes报道，在上海疫情趋缓，防疫管控开始放松后，苹果供应商广达正在逐步恢复其中国工厂的MacBook产品生产。': 0.9999,
+             '仍有许多苹果笔记本用户在等待3月和4月订购的MacBook Pro机型到货，由于苹果的供应问题，他们的发货时间被大大推迟了。': 0.5800,
+             '尽管MacBook Pro的生产逐渐恢复，但供应问题预计依然影响2022年第三季度的产品销售。': 0.5422}
+        """
+        assert text, 'Text has to be non-empty.'
+        return self._send_post_json(self._url + '/extractive_summarization', {
+            'text': text,
+            'language': language or self._language,
+            'topk': topk,
+        })
+
+    def grammatical_error_correction(self, text: Union[str, List[str]], language: str = None) \
+            -> Union[str, List[str]]:
+        """ Grammatical Error Correction (GEC) is the task of correcting different kinds of errors in text such as
+        spelling, punctuation, grammatical, and word choice errors.
+
+        Args:
+            text: Text potentially containing different kinds of errors in text such as spelling, punctuation,
+                grammatical, and word choice errors.
+            language: The language of input text. ``None`` to use the default language.
+
+        Returns:
+            Corrected text.
+
+        Examples::
+
+            HanLP.grammatical_error_correction(['每个青年都应当有远大的报复。', '有的同学对语言很兴趣。'])
+            # Output:
+            [
+                '每个青年都应当有远大的抱负。',
+                '有的同学对语言很有兴趣。'
+            ]
+
+        """
+        response = self._send_post_json(self._url + '/grammatical_error_correction',
+                                        {'text': text,
+                                         'language': language or self._language})
+        return response
